@@ -34,6 +34,7 @@ typedef struct FFGPUResult
     FFstrbuf name;
     FFstrbuf driver;
     FFstrbuf platformApi;
+    FFstrbuf memoryType;
     double temperature;
     double coreUsage;
     int32_t coreCount;
@@ -48,6 +49,7 @@ const char* ffDetectGPUImpl(const FFGPUOptions* options, FFlist* gpus);
 
 const char* ffGPUGetVendorString(unsigned vendorId);
 
-#if defined(__linux__) || defined(__FreeBSD__) || defined(__sun) || defined(__NetBSD__) || defined(__OpenBSD__)
+#if defined(__linux__) || defined(__FreeBSD__) || defined(__sun) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__HAIKU__)
 void ffGPUFillVendorAndName(uint8_t subclass, uint16_t vendor, uint16_t device, FFGPUResult* gpu);
+void ffGPUQueryAmdGpuName(uint16_t deviceId, uint8_t revisionId, FFGPUResult* gpu);
 #endif
